"use client"

import { Select, SelectContent, SelectGroup, SelectItem, SelectLabel, SelectTrigger, SelectValue } from "@/components/ui/select"
import { usePathname, useRouter, useSearchParams } from "next/navigation"
import { useEffect, useState } from "react"
import { Icons } from "./icons"
import { Button } from "./ui/button"
import { Card } from "./ui/card"

export default function Sort() {
    const router = useRouter()
    const pathname = usePathname()
    const searchParams = useSearchParams()

    const search = searchParams.get('search')
    const cat = searchParams.get('category')
    const gen = searchParams.get('genre')
    const plat = searchParams.get('platform')
    const sortm = searchParams.get('sortby')
    const sorto = searchParams.get('order')

    const [isSetByUser, setIsSetByUser] = useState(false)

    const [selectedCategory, setSelectedCategory] = useState(cat || '')
    const [selectedGenre, setSelectedGenre] = useState(gen || '')
    const [selectedPlatform, setSelectedPlatform] = useState(plat || '')
    const [selectedSortMethod, setSelectedSortMethod] = useState(sortm || 'total_rating_count')
    const [selectedSortOrder, setSelectedSortOrder] = useState(sorto || 'desc')

    const urlParams = {
        search: search ? `search=${search}` : '',
        category: selectedCategory ? `category=${selectedCategory}` : '',
        genre: selectedGenre ? `genre=${selectedGenre}` : '',
        platform: selectedPlatform ? `platform=${selectedPlatform}` : '',
        sortMethod: selectedSortMethod ? `sortby=${selectedSortMethod}` : '',
        sortOrder: selectedSortOrder ? `order=${selectedSortOrder}` : '',
    }

    const queryParamString = Object.values(urlParams)
        .filter(Boolean)
        .map((param, index) => (index === 0 ? `?${param}` : `&${param}`))
        .join('')

    const url = `${pathname}${queryParamString ? `${queryParamString}` : ''}`

    useEffect(() => {
        if (url && isSetByUser) {
            router.push(url)
        }
    }, [isSetByUser, router, url])

    function toggleSortOrder() {
        const newSortOrder = selectedSortOrder === 'desc' ? 'asc' : 'desc'
        setSelectedSortOrder(newSortOrder)
    }

    function onReset() {
        router.replace(pathname + (search ? `?search=${search}` : ''))
        setSelectedCategory('')
        setSelectedGenre('')
        setSelectedPlatform('')
        setSelectedSortMethod('total_rating_count')
        setSelectedSortOrder('desc')
        setIsSetByUser(false)
    }

    return (
        <Card className="p-6 grid items-start gap-2 bg-secondary">
            <h1 className="font-bold">Filter</h1>
            <Select value={selectedCategory ? selectedCategory : undefined} key={selectedCategory[0]}
                onValueChange={(value) => {
                    setSelectedCategory(value)
                    setIsSetByUser(true)
                }}>
                <SelectTrigger className={`bg-background border-none w-full ${selectedCategory[0] ? 'font-extrabold' : ''}`}>
                    <SelectValue placeholder="By category..." />
                </SelectTrigger>
                <SelectContent>
                    <SelectGroup>
                        <SelectLabel>Category</SelectLabel>
                        <SelectItem value="main_game">Main Game</SelectItem>
                        <SelectItem value="dlc_addon">DLC Addon</SelectItem>
                        <SelectItem value="expansion">Expansion</SelectItem>
                        <SelectItem value="remake">Remake</SelectItem>
                        <SelectItem value="remaster">Remaster</SelectItem>
                        <SelectItem value="port">Port</SelectItem>
                    </SelectGroup>
                </SelectContent>
            </Select>

            <Select value={selectedGenre ? selectedGenre : undefined} key={selectedGenre[0]}
                onValueChange={(value) => {
                    setSelectedGenre(value)
                    setIsSetByUser(true)
                }}>
                <SelectTrigger className={`bg-background border-none w-full ${selectedGenre[0] ? 'font-extrabold' : ''}`}>
                    <SelectValue placeholder="By genre..." />
                </SelectTrigger>
                <SelectContent className="max-h-52">
                    <SelectGroup>
                        <SelectLabel>Genre</SelectLabel>
                        <SelectItem value="fighting">Fighting</SelectItem>
                        <SelectItem value="shooter">Shooter</SelectItem>
                        <SelectItem value="music">Music</SelectItem>
                        <SelectItem value="platform">Platformer</SelectItem>
                        <SelectItem value="puzzle">Puzzle</SelectItem>
                        <SelectItem value="role-playing-rpg">Role-playing</SelectItem>
                        <SelectItem value="simulator">Simulation</SelectItem>
                        <SelectItem value="sport">Sport</SelectItem>
                        <SelectItem value="tactical">Tactical</SelectItem>
                        <SelectItem value="quiz-trivia">Quiz/Trivia</SelectItem>
                        <SelectItem value="hack-and-slash-beat-em-up">Hack and slash</SelectItem>
                        <SelectItem value="pinball">Pinball</SelectItem>
                        <SelectItem value="adventure">Adventure</SelectItem>
                        <SelectItem value="arcade">Arcade</SelectItem>
                        <SelectItem value="visual-novel">Visual Novel</SelectItem>
                        <SelectItem value="adventure">Adventure</SelectItem>
                        <SelectItem value="moba">Moba</SelectItem>
                        <SelectItem value="point-and-click">Point-and-click</SelectItem>
                    </SelectGroup>
                </SelectContent>
            </Select>

            <Select value={selectedPlatform ? selectedPlatform : undefined} key={selectedPlatform[0]}
                onValueChange={(value) => {
                    setSelectedPlatform(value)
                    setIsSetByUser(true)
                }}>
                <SelectTrigger className={`bg-background border-none w-full ${selectedPlatform[0] ? 'font-extrabold' : ''}`}>
                    <SelectValue placeholder="By Platform..." />
                </SelectTrigger>
                <SelectContent>
                    <SelectGroup>
                        <SelectLabel>Platform</SelectLabel>
                        <SelectItem value="pc">PC</SelectItem>
                        <SelectItem value="playstation">Playstation</SelectItem>
                        <SelectItem value="xbox">Xbox</SelectItem>
                        <SelectItem value="nintendo">Nintendo</SelectItem>
                    </SelectGroup>
                </SelectContent>
            </Select>

            <h1 className="pt-6 font-bold">Sort by</h1>
            <div className="flex space-x-2 pb-1">
                <Select value={selectedSortMethod}
                    onValueChange={(value) => {
                        setSelectedSortMethod(value)
                        setIsSetByUser(true)
                    }}>
                    <SelectTrigger className="bg-background border-none w-full">
                        <SelectValue placeholder="Rating" />
                    </SelectTrigger>
                    <SelectContent>
                        <SelectGroup>
                            <SelectLabel>Sorting</SelectLabel>
                            <SelectItem value="name">Name</SelectItem>
                            <SelectItem value="total_rating_count">Rating</SelectItem>
                        </SelectGroup>
                    </SelectContent>
                </Select>
                <Button variant="ghost"
                    onClick={() => {
                        toggleSortOrder()
                        setIsSetByUser(true)
                    }}
                    className="bg-background border-none">
                    <Icons.arrowdown className={`h-4 w-4 transition-all transform ${selectedSortOrder === 'asc' ? 'rotate-180' : ''}`} />
                </Button>
            </div>

            <Button variant="outline" onClick={() => onReset()}>Reset to Default</Button>
        </Card>
    )
}