"use client"

import { InfiniteGweets } from "@/components/gweets/components/infinite-gweets"
import { useGweets } from "@/components/gweets/hooks/use-gweets"
import LoadingItem from "@/components/loading-item"
import { UserItem } from "@/components/profile/components/user-item"
import { TryAgain } from "@/components/try-again"
import { Card } from "@/components/ui/card"
import { Separator } from "@/components/ui/separator"
import { useSearchParams } from "next/navigation"
import { useSearchPeople } from "../hooks/use-search-people"
import { NoResults } from "./no-results"

export const SearchResults = () => {
    const searchParams = useSearchParams()
    const query = decodeURIComponent(searchParams?.get("query") || "")

    const gweets = useGweets({
        queryKey: ["gweets", "query: ", query],
        type: "search",
        id: query,
    })

    const people = useSearchPeople(query)

    if (gweets.isLoading || gweets.isFetching) return <LoadingItem />

    if (gweets.isError) return <TryAgain />

    return (
        <Card className="p-6 h-full w-full">
            {gweets?.data?.pages &&
                gweets?.data?.pages[0]?.gweets?.length === 0 &&
                people?.data?.length === 0 ? (
                <NoResults query={query} />
            ) : (
                <>
                    {people?.isSuccess && people?.data?.length > 0 && (
                        <>
                            <h1 className="font-bold pb-3">People</h1>
                            {people?.data?.map((person) => {
                                return <UserItem key={person?.id} user={person} sessionId={undefined} />
                            })}
                            {gweets?.data?.pages[0]?.gweets?.length !== 0 &&
                                <Separator className="my-6 p-0.5" />
                            }
                        </>
                    )}

                    {gweets?.data?.pages[0]?.gweets?.length !== 0 &&
                        <>
                            <h1 className="font-bold pb-3">Gweets</h1>
                            <InfiniteGweets
                                gweets={gweets.data}
                                hasNextPage={gweets.hasNextPage}
                                fetchNextPage={gweets.fetchNextPage}
                                isSuccess={gweets.isSuccess}
                                isFetchingNextPage={gweets.isFetchingNextPage}
                            />
                        </>
                    }
                </>
            )}
        </Card>
    )
}